"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WACC = void 0;
/**
 * Weighted Average Cost of Capital (WACC) is the rate that a company is expected to pay on average to all its security holders to finance its assets.
 *
 * @see http://en.wikipedia.org/wiki/Weighted_average_cost_of_capital
 * @param param0
 * @returns
 */
function WACC({ marketValueOfEquity, marketValueOfDebt, costOfEquity, costOfDebt, taxRate, }) {
    const E = marketValueOfEquity;
    const D = marketValueOfDebt;
    const V = marketValueOfEquity + marketValueOfDebt;
    const Re = costOfEquity;
    const Rd = costOfDebt;
    const T = taxRate;
    const WACC = ((E / V) * Re) / 100 + (((D / V) * Rd) / 100) * (1 - T / 100);
    return Math.round(WACC * 1000) / 10;
}
exports.WACC = WACC;
//# sourceMappingURL=WACC.js.map